"""Common Git tasks."""

from invoke import Collection, task
from invoke.exceptions import Failure


def init(ctx, gitflow=True):
    """Init scm repo (if required).

    Raises:
        Failure: .gitignore does not exist

    Returns:
        None
    """
    if not Path('.gitignore').is_file():
        raise Failure('.gitignore does not exist')

    is_new_repo = not Path('.git').is_dir()
    uri_remote = f'git@github.com:{GITHUB_USERNAME}/{GITHUB_SLUG}.git'
    commit_msg = f'new package from midwatch/cc-py3-pkg ({CC_VERSION})'
    branches = ['main']

    if is_new_repo:
        ctx.run('git init')
        ctx.run('git add .')
        ctx.run('git commit -m "{commit_msg}"')
        ctx.run('git branch -M main')
        ctx.run('git remote add origin {}'.format(uri_remote))
        ctx.run('git tag -a "v_0.0.0" -m "cookiecutter ref"')

    if gitflow:
        ctx.run('git flow init -d')
        ctx.run('git flow config set versiontagprefix v_')
        branches.append('develop')

    if is_new_repo:
        for branch in branches:
            ctx.run(f'git push -u origin {branch}')

        ctx.run('git push --tags')


@task
def push(ctx):
    """Push all branches and tags to origin."""

    ctx.run('git push --all')
    ctx.run('git push --tags')


@task
def status(ctx):
    """Show status of remote branches."""
    ctx.run(
        'git for-each-ref --format="%(refname:short) %(upstream:track)" refs/heads'
    )


collection = Collection()
collection.add_task(push)
collection.add_task(status)



"""Top-level package for MW Dry Invoke."""

__author__ = """Justin Stout"""
__email__ = 'midwatch@jstout.us'
__version__ = '0.2.1'

from invoke import task
from invoke.exceptions import Failure


@task(help={'part': "major, minor, or patch/hotfix"})
def bumpversion(ctx, part):
    """Bump project version: major, minor, patch/hotfix

    Raises:
        Failure: part not in [major, minor, patch]
    """
    part = 'patch' if part == 'hotfix' else part

    if part not in ['major', 'minor', 'patch']:
        raise Failure('Not a valid part')

    ctx.run(f'bump2version --no-tag {part}')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mw_dry_invoke', 'tests']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'mw-dry-invoke',
    'version': '0.2.1',
    'description': 'Common Invoke tasks.',
    'long_description': '\nCommon Invoke tasks\n\n* Free software: MIT License\n\nFeatures\n--------\n\n* TODO\n\n\nCredits\n-------\n\nThis package was created with Cookiecutter_ and the `midwatch/cc-py3-pkg`_ project template.\n\n.. _Cookiecutter: https://github.com/audreyr/cookiecutter\n.. _`midwatch/cc-py3-pkg`: https://github.com/midwatch/cc-py3-pkg\n',
    'author': 'Justin Stout',
    'author_email': 'midwatch@jstout.us',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/midwatch/mw_dry_invoke',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
